@@ -1,7 +1,7 @@
 package JobCenter::Client::Mojo;
 use Mojo::Base 'Mojo::EventEmitter';
 
-our $VERSION = '0.37'; # VERSION
+our $VERSION = '0.38'; # VERSION
 
 #
 # Mojo's default reactor uses EV, and EV does not play nice with signals
@@ -476,7 +476,7 @@ sub work {
 		$self->ioloop->stop;
 	});
 
-	$self->{__exit__} = WORK_OK;
+	$self->ioloop->{__exit__} = WORK_OK;
 	$self->log->debug('JobCenter::Client::Mojo starting work');
 	$self->ioloop->start unless Mojo::IOLoop->is_running;
 	$self->log->debug('JobCenter::Client::Mojo done?');
